==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Vae jmno");
define("_OK","Ok!");
define("_COMMENT","koment");
define("_CONFIGURE","Nastaven");
define("_LOGINCREATE","Pihlsit/Vytvoit et");
define("_THRESHOLD","Prhy");
define("_NOCOMMENTS","Bez komente");
define("_NESTED","Vkldan");
define("_FLAT","Patra");
define("_THREAD","Strom");
define("_OLDEST","Nejdve star");
define("_NEWEST","Nejdve novj");
define("_HIGHEST","Nejdve s nejvym skre");
define("_COMMENTSWARNING","Za obsah komente zodpovd jeho autor.");
define("_SCORE","Skre:");
define("_USERINFO","O uivateli");
define("_READREST","Pest zbytek komente...");
define("_REPLY","Odpovdt");
define("_REPLYMAIN","Poslat koment");
define("_NOSUBJECT","Chyb pedmt");
define("_NOANONCOMMENTS","Nen povoleno poslat komente anonymn, prosm <a href=\"modules.php?name=Your_Account\">registrijte se</a>");
define("_PARENT","Nadazen");
define("_ROOT","Hlavn");
define("_UCOMMENT","Koment");
define("_ALLOWEDHTML","Povolit HTML:");
define("_POSTANON","Poslat anonymn");
define("_EXTRANS","Extrans (html tagy do textu)");
define("_HTMLFORMATED","HTML formtovn");
define("_PLAINTEXT","Prost text");
define("_ONN","na...");
define("_SUBJECT","Pedmt");
define("_SURVEYCOM","Koment k anket");
define("_SURVEYCOMPRE","Prohldnout koment k anket");
define("_NOTRIGHT","S touto funkc nen nco v podku.");
define("_DIRECTCOM","Pm koment k anket...");
define("_SENDAMSG","Poslat zprvu");
define("_PASTSURVEYS","Star ankety");



define("_LVOTES","hlasovalo");
define("_TOTALVOTES","Celkem hlasovalo:");
define("_VOTING","Strnka anket");
define("_OTHERPOLLS","Dal ankety");
define("_CURRENTSURVEY","Aktuln anketa");
define("_CURRENTPOLLRESULTS","Vsledky aktuln ankety");
define("_PREVIEW","Prohldnout");
define("_REFRESH","Obnovit");
define("_SURVEYS","Ankety");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Vae jmno");
define("_OK","Ok!");
define("_COMMENT","koment");
define("_CONFIGURE","Nastaven");
define("_LOGINCREATE","Pihlsit/Vytvoit et");
define("_THRESHOLD","Prhy");
define("_NOCOMMENTS","Bez komente");
define("_NESTED","Vkldan");
define("_FLAT","Patra");
define("_THREAD","Strom");
define("_OLDEST","Nejdve star");
define("_NEWEST","Nejdve novj");
define("_HIGHEST","Nejdve s nejvym skre");
define("_COMMENTSWARNING","Za obsah komente zodpovd jeho autor.");
define("_SCORE","Skre:");
define("_USERINFO","O uivateli");
define("_READREST","Pest zbytek komente...");
define("_REPLY","Odpovdt");
define("_REPLYMAIN","Poslat koment");
define("_NOSUBJECT","Chyb pedmt");
define("_NOANONCOMMENTS","Nen povoleno poslat komente anonymn, prosm <a href=\"modules.php?name=Your_Account\">registrijte se</a>");
define("_PARENT","Nadazen");
define("_ROOT","Hlavn");
define("_UCOMMENT","Koment");
define("_ALLOWEDHTML","Povolit HTML:");
define("_POSTANON","Poslat anonymn");
define("_EXTRANS","Extrans (html tagy do textu)");
define("_HTMLFORMATED","HTML formtovn");
define("_PLAINTEXT","Prost text");
define("_ONN","na...");
define("_SUBJECT","Pedmt");
define("_SURVEYCOM","Koment k anket");
define("_SURVEYCOMPRE","Prohldnout koment k anket");
define("_NOTRIGHT","S touto funkc nen nco v podku.");
define("_DIRECTCOM","Pm koment k anket...");
define("_SENDAMSG","Poslat zprvu");
define("_PASTSURVEYS","Star ankety");



define("_LVOTES","hlasovalo");
define("_TOTALVOTES","Celkem hlasovalo:");
define("_VOTING","Strnka anket");
define("_OTHERPOLLS","Dal ankety");
define("_CURRENTSURVEY","Aktuln anketa");
define("_CURRENTPOLLRESULTS","Vsledky aktuln ankety");
define("_PREVIEW","Prohldnout");
define("_REFRESH","Obnovit");
define("_SURVEYS","Ankety");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
